@@ -5,16 +5,24 @@ pub fn to_str(bytes: Vec<u8>) -> String {
 
     let mut s: String = String::with_capacity(bytes.len() * 8);
 
+    let mut s_vec: Vec<String> = Vec::new();
+
     for b in bytes {
 
         let mut b_str: String = String::new();
 
         write!(&mut b_str, "{:b}", b).unwrap();
 
-        let rev_b_str: String = b_str.chars().rev().collect::<String>();
+        s_vec.push(b_str);
 
-        s.push_str(&rev_b_str);
+    }
 
+    s_vec.reverse();
+
+    for i in s_vec {
+
+        s.push_str(&i)
+        
     }
 
     s
